@@ -22,12 +22,12 @@ util ln => sub {
     return $line + $diff;
 };
 
-util result_line_numbers_are => sub {
+tester result_line_numbers_are => sub {
     my ( $results, @numbers ) = @_;
     result(
         pass => 0,
         name => "result+line counts match",
-        stdout => "Number of results, and number of line numbers do not match"
+        stderr => "Number of results, and number of line numbers do not match"
     ) unless @$results == @numbers;
 
     my $count = 0;
@@ -48,10 +48,8 @@ sub result_line_number_is {
     result(
         pass => $pass,
         name => $name,
-        $pass ? () : (stdout => [ "Got: " . $result->line, "Wanted: $number" ]),
+        $pass ? () : (stderr => [ "Got: " . $result->line, "Wanted: $number" ]),
     );
 };
 
-
-
 1;
