@@ -2,9 +2,10 @@ package Fennec::Util;
 use strict;
 use warnings;
 
-use base 'Fennec::Base';
+use Carp;
 
 sub package_subs {
+    my $class = shift;
     my ( $package, $match ) = @_;
     $package = $package . '::';
     no strict 'refs';
@@ -13,6 +14,14 @@ sub package_subs {
     return grep { $_ =~ $match } @list;
 }
 
+sub package_sub_map {
+    my $class = shift;
+    my ( $package, $match ) = @_;
+    croak( "Must specify a package" ) unless $package;
+    my @list = $class->package_subs( @_ );
+    return map {[ $_, $package->can( $_ )]} @list;
+}
+
 1;
 
 =head1 AUTHORS
